/*
 * @Copyright 2010, MechSoft 
 * MechSoft, Mechanical and Software Solutions 
 * 
 * Licensed under the Apache License, Version 2.0 (the 
 * "License"); you may not use this file except in compliance 
 * with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.defne.jsf;

import javax.faces.context.ExternalContext;
import javax.faces.context.FacesContext;

import org.defne.utility.log.ILogger;
import org.defne.utility.log.LoggerProvider;

/**
 * Some utility methods related with
 * the JSF.
 * @author gurkanerdogdu
 * @version $Id$
 */
public final class JSFUtility
{
    /**Logger instance*/
    private static final ILogger logger = LoggerProvider.getLogProvider(JSFUtility.class);
    
    //Private constructor
    private JSFUtility()
    {
        //No instantiate even with reflection etc.
        throw new UnsupportedOperationException();
    }

    /**
     * Gets faces context.
     * @return the JSF faces context
     */
    public static FacesContext getFacesContext()
    {
        return FacesContext.getCurrentInstance();
    }
    
    /**
     * Gets external context.
     * @return the JSF external context
     */
    public static ExternalContext getExternalContext()
    {
        FacesContext ctx = getFacesContext();
        if(ctx != null)
        {
            return ctx.getExternalContext();
        }
        
        return null;
    }
    
    /**
     * Gets application context initialization
     * parameter with the given name. If no parameter
     * is found returns a null.
     * @param parameterName initialization parameter
     * @return an initialization parameter value with the given name
     */
    public static String getInitParameter(String parameterName)
    {
        if(logger.isTraceEnabled())
        {
            logger.trace("Trying to get application initialization parameter with name : " + parameterName);
        }
        
        ExternalContext ctx = getExternalContext();
        if(ctx != null)
        {
            return ctx.getInitParameter(parameterName);
        }
        
        if(logger.isTraceEnabled())
        {
            logger.trace("Initialization parameter with name : " + parameterName + " not found");
        }
        
        return null;
    }
    
}   
